from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.UI.Text
import win32more.Windows.Foundation
import win32more.Windows.Storage.Streams
import win32more.Windows.UI
import win32more.Windows.UI.Text
class CaretType(Enum, Int32):
    Normal = 0
    Null = 1
class FindOptions(Enum, UInt32):
    None_ = 0
    Word = 2
    Case = 4
class _FontWeights_Meta_(ComPtr.__class__):
    pass
class FontWeights(ComPtr, metaclass=_FontWeights_Meta_):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Text.IFontWeights
    _classid_ = 'Microsoft.UI.Text.FontWeights'
    @winrt_classmethod
    def get_Black(cls: win32more.Microsoft.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_Bold(cls: win32more.Microsoft.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_ExtraBlack(cls: win32more.Microsoft.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_ExtraBold(cls: win32more.Microsoft.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_ExtraLight(cls: win32more.Microsoft.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_Light(cls: win32more.Microsoft.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_Medium(cls: win32more.Microsoft.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_Normal(cls: win32more.Microsoft.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_SemiBold(cls: win32more.Microsoft.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_SemiLight(cls: win32more.Microsoft.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_Thin(cls: win32more.Microsoft.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    _FontWeights_Meta_.Black = property(get_Black, None)
    _FontWeights_Meta_.Bold = property(get_Bold, None)
    _FontWeights_Meta_.ExtraBlack = property(get_ExtraBlack, None)
    _FontWeights_Meta_.ExtraBold = property(get_ExtraBold, None)
    _FontWeights_Meta_.ExtraLight = property(get_ExtraLight, None)
    _FontWeights_Meta_.Light = property(get_Light, None)
    _FontWeights_Meta_.Medium = property(get_Medium, None)
    _FontWeights_Meta_.Normal = property(get_Normal, None)
    _FontWeights_Meta_.SemiBold = property(get_SemiBold, None)
    _FontWeights_Meta_.SemiLight = property(get_SemiLight, None)
    _FontWeights_Meta_.Thin = property(get_Thin, None)
class FormatEffect(Enum, Int32):
    Off = 0
    On = 1
    Toggle = 2
    Undefined = 3
class HorizontalCharacterAlignment(Enum, Int32):
    Left = 0
    Right = 1
    Center = 2
class IFontWeights(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Text.IFontWeights'
    _iid_ = Guid('{386cd040-5404-5a8d-8bc7-2ca989f5c065}')
class IFontWeightsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Text.IFontWeightsStatics'
    _iid_ = Guid('{cc390df6-76b0-5807-8b9d-e949a4e623ae}')
    @winrt_commethod(6)
    def get_Black(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(7)
    def get_Bold(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(8)
    def get_ExtraBlack(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(9)
    def get_ExtraBold(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(10)
    def get_ExtraLight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(11)
    def get_Light(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(12)
    def get_Medium(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(13)
    def get_Normal(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(14)
    def get_SemiBold(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(15)
    def get_SemiLight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(16)
    def get_Thin(self) -> win32more.Windows.UI.Text.FontWeight: ...
    Black = property(get_Black, None)
    Bold = property(get_Bold, None)
    ExtraBlack = property(get_ExtraBlack, None)
    ExtraBold = property(get_ExtraBold, None)
    ExtraLight = property(get_ExtraLight, None)
    Light = property(get_Light, None)
    Medium = property(get_Medium, None)
    Normal = property(get_Normal, None)
    SemiBold = property(get_SemiBold, None)
    SemiLight = property(get_SemiLight, None)
    Thin = property(get_Thin, None)
class ITextCharacterFormat(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Text.ITextCharacterFormat'
    _iid_ = Guid('{f5710050-98e5-5788-b1e3-32191eebf94d}')
    @winrt_commethod(6)
    def get_AllCaps(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(7)
    def put_AllCaps(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(8)
    def get_BackgroundColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(9)
    def put_BackgroundColor(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(10)
    def get_Bold(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(11)
    def put_Bold(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(12)
    def get_FontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(13)
    def put_FontStretch(self, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_commethod(14)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(15)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(16)
    def get_ForegroundColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(17)
    def put_ForegroundColor(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(18)
    def get_Hidden(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(19)
    def put_Hidden(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(20)
    def get_Italic(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(21)
    def put_Italic(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(22)
    def get_Kerning(self) -> Single: ...
    @winrt_commethod(23)
    def put_Kerning(self, value: Single) -> Void: ...
    @winrt_commethod(24)
    def get_LanguageTag(self) -> WinRT_String: ...
    @winrt_commethod(25)
    def put_LanguageTag(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(26)
    def get_LinkType(self) -> win32more.Microsoft.UI.Text.LinkType: ...
    @winrt_commethod(27)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(28)
    def put_Name(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(29)
    def get_Outline(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(30)
    def put_Outline(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(31)
    def get_Position(self) -> Single: ...
    @winrt_commethod(32)
    def put_Position(self, value: Single) -> Void: ...
    @winrt_commethod(33)
    def get_ProtectedText(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(34)
    def put_ProtectedText(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(35)
    def get_Size(self) -> Single: ...
    @winrt_commethod(36)
    def put_Size(self, value: Single) -> Void: ...
    @winrt_commethod(37)
    def get_SmallCaps(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(38)
    def put_SmallCaps(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(39)
    def get_Spacing(self) -> Single: ...
    @winrt_commethod(40)
    def put_Spacing(self, value: Single) -> Void: ...
    @winrt_commethod(41)
    def get_Strikethrough(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(42)
    def put_Strikethrough(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(43)
    def get_Subscript(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(44)
    def put_Subscript(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(45)
    def get_Superscript(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(46)
    def put_Superscript(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(47)
    def get_TextScript(self) -> win32more.Microsoft.UI.Text.TextScript: ...
    @winrt_commethod(48)
    def put_TextScript(self, value: win32more.Microsoft.UI.Text.TextScript) -> Void: ...
    @winrt_commethod(49)
    def get_Underline(self) -> win32more.Microsoft.UI.Text.UnderlineType: ...
    @winrt_commethod(50)
    def put_Underline(self, value: win32more.Microsoft.UI.Text.UnderlineType) -> Void: ...
    @winrt_commethod(51)
    def get_Weight(self) -> Int32: ...
    @winrt_commethod(52)
    def put_Weight(self, value: Int32) -> Void: ...
    @winrt_commethod(53)
    def SetClone(self, value: win32more.Microsoft.UI.Text.ITextCharacterFormat) -> Void: ...
    @winrt_commethod(54)
    def GetClone(self) -> win32more.Microsoft.UI.Text.ITextCharacterFormat: ...
    @winrt_commethod(55)
    def IsEqual(self, format: win32more.Microsoft.UI.Text.ITextCharacterFormat) -> Boolean: ...
    AllCaps = property(get_AllCaps, put_AllCaps)
    BackgroundColor = property(get_BackgroundColor, put_BackgroundColor)
    Bold = property(get_Bold, put_Bold)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    ForegroundColor = property(get_ForegroundColor, put_ForegroundColor)
    Hidden = property(get_Hidden, put_Hidden)
    Italic = property(get_Italic, put_Italic)
    Kerning = property(get_Kerning, put_Kerning)
    LanguageTag = property(get_LanguageTag, put_LanguageTag)
    LinkType = property(get_LinkType, None)
    Name = property(get_Name, put_Name)
    Outline = property(get_Outline, put_Outline)
    Position = property(get_Position, put_Position)
    ProtectedText = property(get_ProtectedText, put_ProtectedText)
    Size = property(get_Size, put_Size)
    SmallCaps = property(get_SmallCaps, put_SmallCaps)
    Spacing = property(get_Spacing, put_Spacing)
    Strikethrough = property(get_Strikethrough, put_Strikethrough)
    Subscript = property(get_Subscript, put_Subscript)
    Superscript = property(get_Superscript, put_Superscript)
    TextScript = property(get_TextScript, put_TextScript)
    Underline = property(get_Underline, put_Underline)
    Weight = property(get_Weight, put_Weight)
class ITextConstantsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Text.ITextConstantsStatics'
    _iid_ = Guid('{cd353b3c-af63-5cfb-918c-0f9c8931a161}')
    @winrt_commethod(6)
    def get_AutoColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(7)
    def get_MinUnitCount(self) -> Int32: ...
    @winrt_commethod(8)
    def get_MaxUnitCount(self) -> Int32: ...
    @winrt_commethod(9)
    def get_UndefinedColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(10)
    def get_UndefinedFloatValue(self) -> Single: ...
    @winrt_commethod(11)
    def get_UndefinedInt32Value(self) -> Int32: ...
    @winrt_commethod(12)
    def get_UndefinedFontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(13)
    def get_UndefinedFontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    AutoColor = property(get_AutoColor, None)
    MaxUnitCount = property(get_MaxUnitCount, None)
    MinUnitCount = property(get_MinUnitCount, None)
    UndefinedColor = property(get_UndefinedColor, None)
    UndefinedFloatValue = property(get_UndefinedFloatValue, None)
    UndefinedFontStretch = property(get_UndefinedFontStretch, None)
    UndefinedFontStyle = property(get_UndefinedFontStyle, None)
    UndefinedInt32Value = property(get_UndefinedInt32Value, None)
class ITextDocument(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Text.ITextDocument'
    _iid_ = Guid('{1149d57d-86a6-59dd-88d9-196f27bc5c85}')
    @winrt_commethod(6)
    def get_CaretType(self) -> win32more.Microsoft.UI.Text.CaretType: ...
    @winrt_commethod(7)
    def put_CaretType(self, value: win32more.Microsoft.UI.Text.CaretType) -> Void: ...
    @winrt_commethod(8)
    def get_DefaultTabStop(self) -> Single: ...
    @winrt_commethod(9)
    def put_DefaultTabStop(self, value: Single) -> Void: ...
    @winrt_commethod(10)
    def get_Selection(self) -> win32more.Microsoft.UI.Text.ITextSelection: ...
    @winrt_commethod(11)
    def get_UndoLimit(self) -> UInt32: ...
    @winrt_commethod(12)
    def put_UndoLimit(self, value: UInt32) -> Void: ...
    @winrt_commethod(13)
    def CanCopy(self) -> Boolean: ...
    @winrt_commethod(14)
    def CanPaste(self) -> Boolean: ...
    @winrt_commethod(15)
    def CanRedo(self) -> Boolean: ...
    @winrt_commethod(16)
    def CanUndo(self) -> Boolean: ...
    @winrt_commethod(17)
    def ApplyDisplayUpdates(self) -> Int32: ...
    @winrt_commethod(18)
    def BatchDisplayUpdates(self) -> Int32: ...
    @winrt_commethod(19)
    def BeginUndoGroup(self) -> Void: ...
    @winrt_commethod(20)
    def EndUndoGroup(self) -> Void: ...
    @winrt_commethod(21)
    def GetDefaultCharacterFormat(self) -> win32more.Microsoft.UI.Text.ITextCharacterFormat: ...
    @winrt_commethod(22)
    def GetDefaultParagraphFormat(self) -> win32more.Microsoft.UI.Text.ITextParagraphFormat: ...
    @winrt_commethod(23)
    def GetRange(self, startPosition: Int32, endPosition: Int32) -> win32more.Microsoft.UI.Text.ITextRange: ...
    @winrt_commethod(24)
    def GetRangeFromPoint(self, point: win32more.Windows.Foundation.Point, options: win32more.Microsoft.UI.Text.PointOptions) -> win32more.Microsoft.UI.Text.ITextRange: ...
    @winrt_commethod(25)
    def GetText(self, options: win32more.Microsoft.UI.Text.TextGetOptions, value: POINTER(WinRT_String)) -> Void: ...
    @winrt_commethod(26)
    def LoadFromStream(self, options: win32more.Microsoft.UI.Text.TextSetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_commethod(27)
    def Redo(self) -> Void: ...
    @winrt_commethod(28)
    def SaveToStream(self, options: win32more.Microsoft.UI.Text.TextGetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_commethod(29)
    def SetDefaultCharacterFormat(self, value: win32more.Microsoft.UI.Text.ITextCharacterFormat) -> Void: ...
    @winrt_commethod(30)
    def SetDefaultParagraphFormat(self, value: win32more.Microsoft.UI.Text.ITextParagraphFormat) -> Void: ...
    @winrt_commethod(31)
    def SetText(self, options: win32more.Microsoft.UI.Text.TextSetOptions, value: WinRT_String) -> Void: ...
    @winrt_commethod(32)
    def Undo(self) -> Void: ...
    @winrt_commethod(33)
    def get_AlignmentIncludesTrailingWhitespace(self) -> Boolean: ...
    @winrt_commethod(34)
    def put_AlignmentIncludesTrailingWhitespace(self, value: Boolean) -> Void: ...
    @winrt_commethod(35)
    def get_IgnoreTrailingCharacterSpacing(self) -> Boolean: ...
    @winrt_commethod(36)
    def put_IgnoreTrailingCharacterSpacing(self, value: Boolean) -> Void: ...
    @winrt_commethod(37)
    def ClearUndoRedoHistory(self) -> Void: ...
    AlignmentIncludesTrailingWhitespace = property(get_AlignmentIncludesTrailingWhitespace, put_AlignmentIncludesTrailingWhitespace)
    CaretType = property(get_CaretType, put_CaretType)
    DefaultTabStop = property(get_DefaultTabStop, put_DefaultTabStop)
    IgnoreTrailingCharacterSpacing = property(get_IgnoreTrailingCharacterSpacing, put_IgnoreTrailingCharacterSpacing)
    Selection = property(get_Selection, None)
    UndoLimit = property(get_UndoLimit, put_UndoLimit)
class ITextDocument2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Text.ITextDocument2'
    _iid_ = Guid('{21febcf1-2110-5879-b1da-b343097e71e1}')
    @winrt_commethod(6)
    def GetMathMode(self) -> win32more.Microsoft.UI.Text.RichEditMathMode: ...
    @winrt_commethod(7)
    def SetMathMode(self, mode: win32more.Microsoft.UI.Text.RichEditMathMode) -> Void: ...
    @winrt_commethod(8)
    def GetMathML(self, value: POINTER(WinRT_String)) -> Void: ...
    @winrt_commethod(9)
    def SetMathML(self, value: WinRT_String) -> Void: ...
class ITextParagraphFormat(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Text.ITextParagraphFormat'
    _iid_ = Guid('{219b6cdf-0d0b-5701-b8a1-6c906b3ebbe1}')
    @winrt_commethod(6)
    def get_Alignment(self) -> win32more.Microsoft.UI.Text.ParagraphAlignment: ...
    @winrt_commethod(7)
    def put_Alignment(self, value: win32more.Microsoft.UI.Text.ParagraphAlignment) -> Void: ...
    @winrt_commethod(8)
    def get_FirstLineIndent(self) -> Single: ...
    @winrt_commethod(9)
    def get_KeepTogether(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(10)
    def put_KeepTogether(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(11)
    def get_KeepWithNext(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(12)
    def put_KeepWithNext(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(13)
    def get_LeftIndent(self) -> Single: ...
    @winrt_commethod(14)
    def get_LineSpacing(self) -> Single: ...
    @winrt_commethod(15)
    def get_LineSpacingRule(self) -> win32more.Microsoft.UI.Text.LineSpacingRule: ...
    @winrt_commethod(16)
    def get_ListAlignment(self) -> win32more.Microsoft.UI.Text.MarkerAlignment: ...
    @winrt_commethod(17)
    def put_ListAlignment(self, value: win32more.Microsoft.UI.Text.MarkerAlignment) -> Void: ...
    @winrt_commethod(18)
    def get_ListLevelIndex(self) -> Int32: ...
    @winrt_commethod(19)
    def put_ListLevelIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(20)
    def get_ListStart(self) -> Int32: ...
    @winrt_commethod(21)
    def put_ListStart(self, value: Int32) -> Void: ...
    @winrt_commethod(22)
    def get_ListStyle(self) -> win32more.Microsoft.UI.Text.MarkerStyle: ...
    @winrt_commethod(23)
    def put_ListStyle(self, value: win32more.Microsoft.UI.Text.MarkerStyle) -> Void: ...
    @winrt_commethod(24)
    def get_ListTab(self) -> Single: ...
    @winrt_commethod(25)
    def put_ListTab(self, value: Single) -> Void: ...
    @winrt_commethod(26)
    def get_ListType(self) -> win32more.Microsoft.UI.Text.MarkerType: ...
    @winrt_commethod(27)
    def put_ListType(self, value: win32more.Microsoft.UI.Text.MarkerType) -> Void: ...
    @winrt_commethod(28)
    def get_NoLineNumber(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(29)
    def put_NoLineNumber(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(30)
    def get_PageBreakBefore(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(31)
    def put_PageBreakBefore(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(32)
    def get_RightIndent(self) -> Single: ...
    @winrt_commethod(33)
    def put_RightIndent(self, value: Single) -> Void: ...
    @winrt_commethod(34)
    def get_RightToLeft(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(35)
    def put_RightToLeft(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(36)
    def get_Style(self) -> win32more.Microsoft.UI.Text.ParagraphStyle: ...
    @winrt_commethod(37)
    def put_Style(self, value: win32more.Microsoft.UI.Text.ParagraphStyle) -> Void: ...
    @winrt_commethod(38)
    def get_SpaceAfter(self) -> Single: ...
    @winrt_commethod(39)
    def put_SpaceAfter(self, value: Single) -> Void: ...
    @winrt_commethod(40)
    def get_SpaceBefore(self) -> Single: ...
    @winrt_commethod(41)
    def put_SpaceBefore(self, value: Single) -> Void: ...
    @winrt_commethod(42)
    def get_WidowControl(self) -> win32more.Microsoft.UI.Text.FormatEffect: ...
    @winrt_commethod(43)
    def put_WidowControl(self, value: win32more.Microsoft.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(44)
    def get_TabCount(self) -> Int32: ...
    @winrt_commethod(45)
    def AddTab(self, position: Single, align: win32more.Microsoft.UI.Text.TabAlignment, leader: win32more.Microsoft.UI.Text.TabLeader) -> Void: ...
    @winrt_commethod(46)
    def ClearAllTabs(self) -> Void: ...
    @winrt_commethod(47)
    def DeleteTab(self, position: Single) -> Void: ...
    @winrt_commethod(48)
    def GetClone(self) -> win32more.Microsoft.UI.Text.ITextParagraphFormat: ...
    @winrt_commethod(49)
    def GetTab(self, index: Int32, position: POINTER(Single), align: POINTER(win32more.Microsoft.UI.Text.TabAlignment), leader: POINTER(win32more.Microsoft.UI.Text.TabLeader)) -> Void: ...
    @winrt_commethod(50)
    def IsEqual(self, format: win32more.Microsoft.UI.Text.ITextParagraphFormat) -> Boolean: ...
    @winrt_commethod(51)
    def SetClone(self, format: win32more.Microsoft.UI.Text.ITextParagraphFormat) -> Void: ...
    @winrt_commethod(52)
    def SetIndents(self, start: Single, left: Single, right: Single) -> Void: ...
    @winrt_commethod(53)
    def SetLineSpacing(self, rule: win32more.Microsoft.UI.Text.LineSpacingRule, spacing: Single) -> Void: ...
    Alignment = property(get_Alignment, put_Alignment)
    FirstLineIndent = property(get_FirstLineIndent, None)
    KeepTogether = property(get_KeepTogether, put_KeepTogether)
    KeepWithNext = property(get_KeepWithNext, put_KeepWithNext)
    LeftIndent = property(get_LeftIndent, None)
    LineSpacing = property(get_LineSpacing, None)
    LineSpacingRule = property(get_LineSpacingRule, None)
    ListAlignment = property(get_ListAlignment, put_ListAlignment)
    ListLevelIndex = property(get_ListLevelIndex, put_ListLevelIndex)
    ListStart = property(get_ListStart, put_ListStart)
    ListStyle = property(get_ListStyle, put_ListStyle)
    ListTab = property(get_ListTab, put_ListTab)
    ListType = property(get_ListType, put_ListType)
    NoLineNumber = property(get_NoLineNumber, put_NoLineNumber)
    PageBreakBefore = property(get_PageBreakBefore, put_PageBreakBefore)
    RightIndent = property(get_RightIndent, put_RightIndent)
    RightToLeft = property(get_RightToLeft, put_RightToLeft)
    SpaceAfter = property(get_SpaceAfter, put_SpaceAfter)
    SpaceBefore = property(get_SpaceBefore, put_SpaceBefore)
    Style = property(get_Style, put_Style)
    TabCount = property(get_TabCount, None)
    WidowControl = property(get_WidowControl, put_WidowControl)
class ITextRange(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Text.ITextRange'
    _iid_ = Guid('{06d4abcf-0c06-5d12-a743-85537efd09ea}')
    @winrt_commethod(6)
    def get_Character(self) -> Char: ...
    @winrt_commethod(7)
    def put_Character(self, value: Char) -> Void: ...
    @winrt_commethod(8)
    def get_CharacterFormat(self) -> win32more.Microsoft.UI.Text.ITextCharacterFormat: ...
    @winrt_commethod(9)
    def put_CharacterFormat(self, value: win32more.Microsoft.UI.Text.ITextCharacterFormat) -> Void: ...
    @winrt_commethod(10)
    def get_FormattedText(self) -> win32more.Microsoft.UI.Text.ITextRange: ...
    @winrt_commethod(11)
    def put_FormattedText(self, value: win32more.Microsoft.UI.Text.ITextRange) -> Void: ...
    @winrt_commethod(12)
    def get_EndPosition(self) -> Int32: ...
    @winrt_commethod(13)
    def put_EndPosition(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def get_Gravity(self) -> win32more.Microsoft.UI.Text.RangeGravity: ...
    @winrt_commethod(15)
    def put_Gravity(self, value: win32more.Microsoft.UI.Text.RangeGravity) -> Void: ...
    @winrt_commethod(16)
    def get_Length(self) -> Int32: ...
    @winrt_commethod(17)
    def get_Link(self) -> WinRT_String: ...
    @winrt_commethod(18)
    def put_Link(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(19)
    def get_ParagraphFormat(self) -> win32more.Microsoft.UI.Text.ITextParagraphFormat: ...
    @winrt_commethod(20)
    def put_ParagraphFormat(self, value: win32more.Microsoft.UI.Text.ITextParagraphFormat) -> Void: ...
    @winrt_commethod(21)
    def get_StartPosition(self) -> Int32: ...
    @winrt_commethod(22)
    def put_StartPosition(self, value: Int32) -> Void: ...
    @winrt_commethod(23)
    def get_StoryLength(self) -> Int32: ...
    @winrt_commethod(24)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(25)
    def put_Text(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(26)
    def CanPaste(self, format: Int32) -> Boolean: ...
    @winrt_commethod(27)
    def ChangeCase(self, value: win32more.Microsoft.UI.Text.LetterCase) -> Void: ...
    @winrt_commethod(28)
    def Collapse(self, value: Boolean) -> Void: ...
    @winrt_commethod(29)
    def Copy(self) -> Void: ...
    @winrt_commethod(30)
    def Cut(self) -> Void: ...
    @winrt_commethod(31)
    def Delete(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_commethod(32)
    def EndOf(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit, extend: Boolean) -> Int32: ...
    @winrt_commethod(33)
    def Expand(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit) -> Int32: ...
    @winrt_commethod(34)
    def FindText(self, value: WinRT_String, scanLength: Int32, options: win32more.Microsoft.UI.Text.FindOptions) -> Int32: ...
    @winrt_commethod(35)
    def GetCharacterUtf32(self, value: POINTER(UInt32), offset: Int32) -> Void: ...
    @winrt_commethod(36)
    def GetClone(self) -> win32more.Microsoft.UI.Text.ITextRange: ...
    @winrt_commethod(37)
    def GetIndex(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit) -> Int32: ...
    @winrt_commethod(38)
    def GetPoint(self, horizontalAlign: win32more.Microsoft.UI.Text.HorizontalCharacterAlignment, verticalAlign: win32more.Microsoft.UI.Text.VerticalCharacterAlignment, options: win32more.Microsoft.UI.Text.PointOptions, point: POINTER(win32more.Windows.Foundation.Point)) -> Void: ...
    @winrt_commethod(39)
    def GetRect(self, options: win32more.Microsoft.UI.Text.PointOptions, rect: POINTER(win32more.Windows.Foundation.Rect), hit: POINTER(Int32)) -> Void: ...
    @winrt_commethod(40)
    def GetText(self, options: win32more.Microsoft.UI.Text.TextGetOptions, value: POINTER(WinRT_String)) -> Void: ...
    @winrt_commethod(41)
    def GetTextViaStream(self, options: win32more.Microsoft.UI.Text.TextGetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_commethod(42)
    def InRange(self, range: win32more.Microsoft.UI.Text.ITextRange) -> Boolean: ...
    @winrt_commethod(43)
    def InsertImage(self, width: Int32, height: Int32, ascent: Int32, verticalAlign: win32more.Microsoft.UI.Text.VerticalCharacterAlignment, alternateText: WinRT_String, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_commethod(44)
    def InStory(self, range: win32more.Microsoft.UI.Text.ITextRange) -> Boolean: ...
    @winrt_commethod(45)
    def IsEqual(self, range: win32more.Microsoft.UI.Text.ITextRange) -> Boolean: ...
    @winrt_commethod(46)
    def Move(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_commethod(47)
    def MoveEnd(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_commethod(48)
    def MoveStart(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_commethod(49)
    def Paste(self, format: Int32) -> Void: ...
    @winrt_commethod(50)
    def ScrollIntoView(self, value: win32more.Microsoft.UI.Text.PointOptions) -> Void: ...
    @winrt_commethod(51)
    def MatchSelection(self) -> Void: ...
    @winrt_commethod(52)
    def SetIndex(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit, index: Int32, extend: Boolean) -> Void: ...
    @winrt_commethod(53)
    def SetPoint(self, point: win32more.Windows.Foundation.Point, options: win32more.Microsoft.UI.Text.PointOptions, extend: Boolean) -> Void: ...
    @winrt_commethod(54)
    def SetRange(self, startPosition: Int32, endPosition: Int32) -> Void: ...
    @winrt_commethod(55)
    def SetText(self, options: win32more.Microsoft.UI.Text.TextSetOptions, value: WinRT_String) -> Void: ...
    @winrt_commethod(56)
    def SetTextViaStream(self, options: win32more.Microsoft.UI.Text.TextSetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_commethod(57)
    def StartOf(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit, extend: Boolean) -> Int32: ...
    Character = property(get_Character, put_Character)
    CharacterFormat = property(get_CharacterFormat, put_CharacterFormat)
    EndPosition = property(get_EndPosition, put_EndPosition)
    FormattedText = property(get_FormattedText, put_FormattedText)
    Gravity = property(get_Gravity, put_Gravity)
    Length = property(get_Length, None)
    Link = property(get_Link, put_Link)
    ParagraphFormat = property(get_ParagraphFormat, put_ParagraphFormat)
    StartPosition = property(get_StartPosition, put_StartPosition)
    StoryLength = property(get_StoryLength, None)
    Text = property(get_Text, put_Text)
class ITextSelection(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Text.ITextSelection'
    _iid_ = Guid('{8f5e6cb1-2b04-589f-bd24-54e5cd8dd399}')
    @winrt_commethod(6)
    def get_Options(self) -> win32more.Microsoft.UI.Text.SelectionOptions: ...
    @winrt_commethod(7)
    def put_Options(self, value: win32more.Microsoft.UI.Text.SelectionOptions) -> Void: ...
    @winrt_commethod(8)
    def get_Type(self) -> win32more.Microsoft.UI.Text.SelectionType: ...
    @winrt_commethod(9)
    def EndKey(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit, extend: Boolean) -> Int32: ...
    @winrt_commethod(10)
    def HomeKey(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit, extend: Boolean) -> Int32: ...
    @winrt_commethod(11)
    def MoveDown(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit, count: Int32, extend: Boolean) -> Int32: ...
    @winrt_commethod(12)
    def MoveLeft(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit, count: Int32, extend: Boolean) -> Int32: ...
    @winrt_commethod(13)
    def MoveRight(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit, count: Int32, extend: Boolean) -> Int32: ...
    @winrt_commethod(14)
    def MoveUp(self, unit: win32more.Microsoft.UI.Text.TextRangeUnit, count: Int32, extend: Boolean) -> Int32: ...
    @winrt_commethod(15)
    def TypeText(self, value: WinRT_String) -> Void: ...
    Options = property(get_Options, put_Options)
    Type = property(get_Type, None)
class LetterCase(Enum, Int32):
    Lower = 0
    Upper = 1
class LineSpacingRule(Enum, Int32):
    Undefined = 0
    Single = 1
    OneAndHalf = 2
    Double = 3
    AtLeast = 4
    Exactly = 5
    Multiple = 6
    Percent = 7
class LinkType(Enum, Int32):
    Undefined = 0
    NotALink = 1
    ClientLink = 2
    FriendlyLinkName = 3
    FriendlyLinkAddress = 4
    AutoLink = 5
    AutoLinkEmail = 6
    AutoLinkPhone = 7
    AutoLinkPath = 8
class MarkerAlignment(Enum, Int32):
    Undefined = 0
    Left = 1
    Center = 2
    Right = 3
class MarkerStyle(Enum, Int32):
    Undefined = 0
    Parenthesis = 1
    Parentheses = 2
    Period = 3
    Plain = 4
    Minus = 5
    NoNumber = 6
class MarkerType(Enum, Int32):
    Undefined = 0
    None_ = 1
    Bullet = 2
    Arabic = 3
    LowercaseEnglishLetter = 4
    UppercaseEnglishLetter = 5
    LowercaseRoman = 6
    UppercaseRoman = 7
    UnicodeSequence = 8
    CircledNumber = 9
    BlackCircleWingding = 10
    WhiteCircleWingding = 11
    ArabicWide = 12
    SimplifiedChinese = 13
    TraditionalChinese = 14
    JapanSimplifiedChinese = 15
    JapanKorea = 16
    ArabicDictionary = 17
    ArabicAbjad = 18
    Hebrew = 19
    ThaiAlphabetic = 20
    ThaiNumeric = 21
    DevanagariVowel = 22
    DevanagariConsonant = 23
    DevanagariNumeric = 24
class ParagraphAlignment(Enum, Int32):
    Undefined = 0
    Left = 1
    Center = 2
    Right = 3
    Justify = 4
class ParagraphStyle(Enum, Int32):
    Undefined = 0
    None_ = 1
    Normal = 2
    Heading1 = 3
    Heading2 = 4
    Heading3 = 5
    Heading4 = 6
    Heading5 = 7
    Heading6 = 8
    Heading7 = 9
    Heading8 = 10
    Heading9 = 11
class PointOptions(Enum, UInt32):
    None_ = 0
    IncludeInset = 1
    Start = 32
    ClientCoordinates = 256
    AllowOffClient = 512
    Transform = 1024
    NoHorizontalScroll = 65536
    NoVerticalScroll = 262144
class RangeGravity(Enum, Int32):
    UIBehavior = 0
    Backward = 1
    Forward = 2
    Inward = 3
    Outward = 4
class RichEditMathMode(Enum, Int32):
    NoMath = 0
    MathOnly = 1
class RichEditTextDocument(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Text.ITextDocument
    _classid_ = 'Microsoft.UI.Text.RichEditTextDocument'
    @winrt_mixinmethod
    def get_CaretType(self: win32more.Microsoft.UI.Text.ITextDocument) -> win32more.Microsoft.UI.Text.CaretType: ...
    @winrt_mixinmethod
    def put_CaretType(self: win32more.Microsoft.UI.Text.ITextDocument, value: win32more.Microsoft.UI.Text.CaretType) -> Void: ...
    @winrt_mixinmethod
    def get_DefaultTabStop(self: win32more.Microsoft.UI.Text.ITextDocument) -> Single: ...
    @winrt_mixinmethod
    def put_DefaultTabStop(self: win32more.Microsoft.UI.Text.ITextDocument, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_Selection(self: win32more.Microsoft.UI.Text.ITextDocument) -> win32more.Microsoft.UI.Text.ITextSelection: ...
    @winrt_mixinmethod
    def get_UndoLimit(self: win32more.Microsoft.UI.Text.ITextDocument) -> UInt32: ...
    @winrt_mixinmethod
    def put_UndoLimit(self: win32more.Microsoft.UI.Text.ITextDocument, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def CanCopy(self: win32more.Microsoft.UI.Text.ITextDocument) -> Boolean: ...
    @winrt_mixinmethod
    def CanPaste(self: win32more.Microsoft.UI.Text.ITextDocument) -> Boolean: ...
    @winrt_mixinmethod
    def CanRedo(self: win32more.Microsoft.UI.Text.ITextDocument) -> Boolean: ...
    @winrt_mixinmethod
    def CanUndo(self: win32more.Microsoft.UI.Text.ITextDocument) -> Boolean: ...
    @winrt_mixinmethod
    def ApplyDisplayUpdates(self: win32more.Microsoft.UI.Text.ITextDocument) -> Int32: ...
    @winrt_mixinmethod
    def BatchDisplayUpdates(self: win32more.Microsoft.UI.Text.ITextDocument) -> Int32: ...
    @winrt_mixinmethod
    def BeginUndoGroup(self: win32more.Microsoft.UI.Text.ITextDocument) -> Void: ...
    @winrt_mixinmethod
    def EndUndoGroup(self: win32more.Microsoft.UI.Text.ITextDocument) -> Void: ...
    @winrt_mixinmethod
    def GetDefaultCharacterFormat(self: win32more.Microsoft.UI.Text.ITextDocument) -> win32more.Microsoft.UI.Text.ITextCharacterFormat: ...
    @winrt_mixinmethod
    def GetDefaultParagraphFormat(self: win32more.Microsoft.UI.Text.ITextDocument) -> win32more.Microsoft.UI.Text.ITextParagraphFormat: ...
    @winrt_mixinmethod
    def GetRange(self: win32more.Microsoft.UI.Text.ITextDocument, startPosition: Int32, endPosition: Int32) -> win32more.Microsoft.UI.Text.ITextRange: ...
    @winrt_mixinmethod
    def GetRangeFromPoint(self: win32more.Microsoft.UI.Text.ITextDocument, point: win32more.Windows.Foundation.Point, options: win32more.Microsoft.UI.Text.PointOptions) -> win32more.Microsoft.UI.Text.ITextRange: ...
    @winrt_mixinmethod
    def GetText(self: win32more.Microsoft.UI.Text.ITextDocument, options: win32more.Microsoft.UI.Text.TextGetOptions, value: POINTER(WinRT_String)) -> Void: ...
    @winrt_mixinmethod
    def LoadFromStream(self: win32more.Microsoft.UI.Text.ITextDocument, options: win32more.Microsoft.UI.Text.TextSetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_mixinmethod
    def Redo(self: win32more.Microsoft.UI.Text.ITextDocument) -> Void: ...
    @winrt_mixinmethod
    def SaveToStream(self: win32more.Microsoft.UI.Text.ITextDocument, options: win32more.Microsoft.UI.Text.TextGetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_mixinmethod
    def SetDefaultCharacterFormat(self: win32more.Microsoft.UI.Text.ITextDocument, value: win32more.Microsoft.UI.Text.ITextCharacterFormat) -> Void: ...
    @winrt_mixinmethod
    def SetDefaultParagraphFormat(self: win32more.Microsoft.UI.Text.ITextDocument, value: win32more.Microsoft.UI.Text.ITextParagraphFormat) -> Void: ...
    @winrt_mixinmethod
    def SetText(self: win32more.Microsoft.UI.Text.ITextDocument, options: win32more.Microsoft.UI.Text.TextSetOptions, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def Undo(self: win32more.Microsoft.UI.Text.ITextDocument) -> Void: ...
    @winrt_mixinmethod
    def get_AlignmentIncludesTrailingWhitespace(self: win32more.Microsoft.UI.Text.ITextDocument) -> Boolean: ...
    @winrt_mixinmethod
    def put_AlignmentIncludesTrailingWhitespace(self: win32more.Microsoft.UI.Text.ITextDocument, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IgnoreTrailingCharacterSpacing(self: win32more.Microsoft.UI.Text.ITextDocument) -> Boolean: ...
    @winrt_mixinmethod
    def put_IgnoreTrailingCharacterSpacing(self: win32more.Microsoft.UI.Text.ITextDocument, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def ClearUndoRedoHistory(self: win32more.Microsoft.UI.Text.ITextDocument) -> Void: ...
    @winrt_mixinmethod
    def GetMathMode(self: win32more.Microsoft.UI.Text.ITextDocument2) -> win32more.Microsoft.UI.Text.RichEditMathMode: ...
    @winrt_mixinmethod
    def SetMathMode(self: win32more.Microsoft.UI.Text.ITextDocument2, mode: win32more.Microsoft.UI.Text.RichEditMathMode) -> Void: ...
    @winrt_mixinmethod
    def GetMathML(self: win32more.Microsoft.UI.Text.ITextDocument2, value: POINTER(WinRT_String)) -> Void: ...
    @winrt_mixinmethod
    def SetMathML(self: win32more.Microsoft.UI.Text.ITextDocument2, value: WinRT_String) -> Void: ...
    AlignmentIncludesTrailingWhitespace = property(get_AlignmentIncludesTrailingWhitespace, put_AlignmentIncludesTrailingWhitespace)
    CaretType = property(get_CaretType, put_CaretType)
    DefaultTabStop = property(get_DefaultTabStop, put_DefaultTabStop)
    IgnoreTrailingCharacterSpacing = property(get_IgnoreTrailingCharacterSpacing, put_IgnoreTrailingCharacterSpacing)
    Selection = property(get_Selection, None)
    UndoLimit = property(get_UndoLimit, put_UndoLimit)
class RichEditTextRange(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Text.ITextRange
    _classid_ = 'Microsoft.UI.Text.RichEditTextRange'
    @winrt_mixinmethod
    def get_Character(self: win32more.Microsoft.UI.Text.ITextRange) -> Char: ...
    @winrt_mixinmethod
    def put_Character(self: win32more.Microsoft.UI.Text.ITextRange, value: Char) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterFormat(self: win32more.Microsoft.UI.Text.ITextRange) -> win32more.Microsoft.UI.Text.ITextCharacterFormat: ...
    @winrt_mixinmethod
    def put_CharacterFormat(self: win32more.Microsoft.UI.Text.ITextRange, value: win32more.Microsoft.UI.Text.ITextCharacterFormat) -> Void: ...
    @winrt_mixinmethod
    def get_FormattedText(self: win32more.Microsoft.UI.Text.ITextRange) -> win32more.Microsoft.UI.Text.ITextRange: ...
    @winrt_mixinmethod
    def put_FormattedText(self: win32more.Microsoft.UI.Text.ITextRange, value: win32more.Microsoft.UI.Text.ITextRange) -> Void: ...
    @winrt_mixinmethod
    def get_EndPosition(self: win32more.Microsoft.UI.Text.ITextRange) -> Int32: ...
    @winrt_mixinmethod
    def put_EndPosition(self: win32more.Microsoft.UI.Text.ITextRange, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Gravity(self: win32more.Microsoft.UI.Text.ITextRange) -> win32more.Microsoft.UI.Text.RangeGravity: ...
    @winrt_mixinmethod
    def put_Gravity(self: win32more.Microsoft.UI.Text.ITextRange, value: win32more.Microsoft.UI.Text.RangeGravity) -> Void: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Microsoft.UI.Text.ITextRange) -> Int32: ...
    @winrt_mixinmethod
    def get_Link(self: win32more.Microsoft.UI.Text.ITextRange) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Link(self: win32more.Microsoft.UI.Text.ITextRange, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ParagraphFormat(self: win32more.Microsoft.UI.Text.ITextRange) -> win32more.Microsoft.UI.Text.ITextParagraphFormat: ...
    @winrt_mixinmethod
    def put_ParagraphFormat(self: win32more.Microsoft.UI.Text.ITextRange, value: win32more.Microsoft.UI.Text.ITextParagraphFormat) -> Void: ...
    @winrt_mixinmethod
    def get_StartPosition(self: win32more.Microsoft.UI.Text.ITextRange) -> Int32: ...
    @winrt_mixinmethod
    def put_StartPosition(self: win32more.Microsoft.UI.Text.ITextRange, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_StoryLength(self: win32more.Microsoft.UI.Text.ITextRange) -> Int32: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.UI.Text.ITextRange) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Microsoft.UI.Text.ITextRange, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def CanPaste(self: win32more.Microsoft.UI.Text.ITextRange, format: Int32) -> Boolean: ...
    @winrt_mixinmethod
    def ChangeCase(self: win32more.Microsoft.UI.Text.ITextRange, value: win32more.Microsoft.UI.Text.LetterCase) -> Void: ...
    @winrt_mixinmethod
    def Collapse(self: win32more.Microsoft.UI.Text.ITextRange, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def Copy(self: win32more.Microsoft.UI.Text.ITextRange) -> Void: ...
    @winrt_mixinmethod
    def Cut(self: win32more.Microsoft.UI.Text.ITextRange) -> Void: ...
    @winrt_mixinmethod
    def Delete(self: win32more.Microsoft.UI.Text.ITextRange, unit: win32more.Microsoft.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_mixinmethod
    def EndOf(self: win32more.Microsoft.UI.Text.ITextRange, unit: win32more.Microsoft.UI.Text.TextRangeUnit, extend: Boolean) -> Int32: ...
    @winrt_mixinmethod
    def Expand(self: win32more.Microsoft.UI.Text.ITextRange, unit: win32more.Microsoft.UI.Text.TextRangeUnit) -> Int32: ...
    @winrt_mixinmethod
    def FindText(self: win32more.Microsoft.UI.Text.ITextRange, value: WinRT_String, scanLength: Int32, options: win32more.Microsoft.UI.Text.FindOptions) -> Int32: ...
    @winrt_mixinmethod
    def GetCharacterUtf32(self: win32more.Microsoft.UI.Text.ITextRange, value: POINTER(UInt32), offset: Int32) -> Void: ...
    @winrt_mixinmethod
    def GetClone(self: win32more.Microsoft.UI.Text.ITextRange) -> win32more.Microsoft.UI.Text.ITextRange: ...
    @winrt_mixinmethod
    def GetIndex(self: win32more.Microsoft.UI.Text.ITextRange, unit: win32more.Microsoft.UI.Text.TextRangeUnit) -> Int32: ...
    @winrt_mixinmethod
    def GetPoint(self: win32more.Microsoft.UI.Text.ITextRange, horizontalAlign: win32more.Microsoft.UI.Text.HorizontalCharacterAlignment, verticalAlign: win32more.Microsoft.UI.Text.VerticalCharacterAlignment, options: win32more.Microsoft.UI.Text.PointOptions, point: POINTER(win32more.Windows.Foundation.Point)) -> Void: ...
    @winrt_mixinmethod
    def GetRect(self: win32more.Microsoft.UI.Text.ITextRange, options: win32more.Microsoft.UI.Text.PointOptions, rect: POINTER(win32more.Windows.Foundation.Rect), hit: POINTER(Int32)) -> Void: ...
    @winrt_mixinmethod
    def GetText(self: win32more.Microsoft.UI.Text.ITextRange, options: win32more.Microsoft.UI.Text.TextGetOptions, value: POINTER(WinRT_String)) -> Void: ...
    @winrt_mixinmethod
    def GetTextViaStream(self: win32more.Microsoft.UI.Text.ITextRange, options: win32more.Microsoft.UI.Text.TextGetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_mixinmethod
    def InRange(self: win32more.Microsoft.UI.Text.ITextRange, range: win32more.Microsoft.UI.Text.ITextRange) -> Boolean: ...
    @winrt_mixinmethod
    def InsertImage(self: win32more.Microsoft.UI.Text.ITextRange, width: Int32, height: Int32, ascent: Int32, verticalAlign: win32more.Microsoft.UI.Text.VerticalCharacterAlignment, alternateText: WinRT_String, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_mixinmethod
    def InStory(self: win32more.Microsoft.UI.Text.ITextRange, range: win32more.Microsoft.UI.Text.ITextRange) -> Boolean: ...
    @winrt_mixinmethod
    def IsEqual(self: win32more.Microsoft.UI.Text.ITextRange, range: win32more.Microsoft.UI.Text.ITextRange) -> Boolean: ...
    @winrt_mixinmethod
    def Move(self: win32more.Microsoft.UI.Text.ITextRange, unit: win32more.Microsoft.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_mixinmethod
    def MoveEnd(self: win32more.Microsoft.UI.Text.ITextRange, unit: win32more.Microsoft.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_mixinmethod
    def MoveStart(self: win32more.Microsoft.UI.Text.ITextRange, unit: win32more.Microsoft.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_mixinmethod
    def Paste(self: win32more.Microsoft.UI.Text.ITextRange, format: Int32) -> Void: ...
    @winrt_mixinmethod
    def ScrollIntoView(self: win32more.Microsoft.UI.Text.ITextRange, value: win32more.Microsoft.UI.Text.PointOptions) -> Void: ...
    @winrt_mixinmethod
    def MatchSelection(self: win32more.Microsoft.UI.Text.ITextRange) -> Void: ...
    @winrt_mixinmethod
    def SetIndex(self: win32more.Microsoft.UI.Text.ITextRange, unit: win32more.Microsoft.UI.Text.TextRangeUnit, index: Int32, extend: Boolean) -> Void: ...
    @winrt_mixinmethod
    def SetPoint(self: win32more.Microsoft.UI.Text.ITextRange, point: win32more.Windows.Foundation.Point, options: win32more.Microsoft.UI.Text.PointOptions, extend: Boolean) -> Void: ...
    @winrt_mixinmethod
    def SetRange(self: win32more.Microsoft.UI.Text.ITextRange, startPosition: Int32, endPosition: Int32) -> Void: ...
    @winrt_mixinmethod
    def SetText(self: win32more.Microsoft.UI.Text.ITextRange, options: win32more.Microsoft.UI.Text.TextSetOptions, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def SetTextViaStream(self: win32more.Microsoft.UI.Text.ITextRange, options: win32more.Microsoft.UI.Text.TextSetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_mixinmethod
    def StartOf(self: win32more.Microsoft.UI.Text.ITextRange, unit: win32more.Microsoft.UI.Text.TextRangeUnit, extend: Boolean) -> Int32: ...
    Character = property(get_Character, put_Character)
    CharacterFormat = property(get_CharacterFormat, put_CharacterFormat)
    EndPosition = property(get_EndPosition, put_EndPosition)
    FormattedText = property(get_FormattedText, put_FormattedText)
    Gravity = property(get_Gravity, put_Gravity)
    Length = property(get_Length, None)
    Link = property(get_Link, put_Link)
    ParagraphFormat = property(get_ParagraphFormat, put_ParagraphFormat)
    StartPosition = property(get_StartPosition, put_StartPosition)
    StoryLength = property(get_StoryLength, None)
    Text = property(get_Text, put_Text)
class SelectionOptions(Enum, UInt32):
    StartActive = 1
    AtEndOfLine = 2
    Overtype = 4
    Active = 8
    Replace = 16
class SelectionType(Enum, Int32):
    None_ = 0
    InsertionPoint = 1
    Normal = 2
    InlineShape = 7
    Shape = 8
class TabAlignment(Enum, Int32):
    Left = 0
    Center = 1
    Right = 2
    Decimal = 3
    Bar = 4
class TabLeader(Enum, Int32):
    Spaces = 0
    Dots = 1
    Dashes = 2
    Lines = 3
    ThickLines = 4
    Equals = 5
TextApiContract: UInt32 = 131072
class _TextConstants_Meta_(ComPtr.__class__):
    pass
class TextConstants(ComPtr, metaclass=_TextConstants_Meta_):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Text.TextConstants'
    @winrt_classmethod
    def get_AutoColor(cls: win32more.Microsoft.UI.Text.ITextConstantsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MinUnitCount(cls: win32more.Microsoft.UI.Text.ITextConstantsStatics) -> Int32: ...
    @winrt_classmethod
    def get_MaxUnitCount(cls: win32more.Microsoft.UI.Text.ITextConstantsStatics) -> Int32: ...
    @winrt_classmethod
    def get_UndefinedColor(cls: win32more.Microsoft.UI.Text.ITextConstantsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_UndefinedFloatValue(cls: win32more.Microsoft.UI.Text.ITextConstantsStatics) -> Single: ...
    @winrt_classmethod
    def get_UndefinedInt32Value(cls: win32more.Microsoft.UI.Text.ITextConstantsStatics) -> Int32: ...
    @winrt_classmethod
    def get_UndefinedFontStretch(cls: win32more.Microsoft.UI.Text.ITextConstantsStatics) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_classmethod
    def get_UndefinedFontStyle(cls: win32more.Microsoft.UI.Text.ITextConstantsStatics) -> win32more.Windows.UI.Text.FontStyle: ...
    _TextConstants_Meta_.AutoColor = property(get_AutoColor, None)
    _TextConstants_Meta_.MaxUnitCount = property(get_MaxUnitCount, None)
    _TextConstants_Meta_.MinUnitCount = property(get_MinUnitCount, None)
    _TextConstants_Meta_.UndefinedColor = property(get_UndefinedColor, None)
    _TextConstants_Meta_.UndefinedFloatValue = property(get_UndefinedFloatValue, None)
    _TextConstants_Meta_.UndefinedFontStretch = property(get_UndefinedFontStretch, None)
    _TextConstants_Meta_.UndefinedFontStyle = property(get_UndefinedFontStyle, None)
    _TextConstants_Meta_.UndefinedInt32Value = property(get_UndefinedInt32Value, None)
class TextGetOptions(Enum, UInt32):
    None_ = 0
    AdjustCrlf = 1
    UseCrlf = 2
    UseObjectText = 4
    AllowFinalEop = 8
    NoHidden = 32
    IncludeNumbering = 64
    FormatRtf = 8192
    UseLf = 16777216
class TextRangeUnit(Enum, Int32):
    Character = 0
    Word = 1
    Sentence = 2
    Paragraph = 3
    Line = 4
    Story = 5
    Screen = 6
    Section = 7
    Window = 8
    CharacterFormat = 9
    ParagraphFormat = 10
    Object = 11
    HardParagraph = 12
    Cluster = 13
    Bold = 14
    Italic = 15
    Underline = 16
    Strikethrough = 17
    ProtectedText = 18
    Link = 19
    SmallCaps = 20
    AllCaps = 21
    Hidden = 22
    Outline = 23
    Shadow = 24
    Imprint = 25
    Disabled = 26
    Revised = 27
    Subscript = 28
    Superscript = 29
    FontBound = 30
    LinkProtected = 31
    ContentLink = 32
class TextScript(Enum, Int32):
    Undefined = 0
    Ansi = 1
    EastEurope = 2
    Cyrillic = 3
    Greek = 4
    Turkish = 5
    Hebrew = 6
    Arabic = 7
    Baltic = 8
    Vietnamese = 9
    Default = 10
    Symbol = 11
    Thai = 12
    ShiftJis = 13
    GB2312 = 14
    Hangul = 15
    Big5 = 16
    PC437 = 17
    Oem = 18
    Mac = 19
    Armenian = 20
    Syriac = 21
    Thaana = 22
    Devanagari = 23
    Bengali = 24
    Gurmukhi = 25
    Gujarati = 26
    Oriya = 27
    Tamil = 28
    Telugu = 29
    Kannada = 30
    Malayalam = 31
    Sinhala = 32
    Lao = 33
    Tibetan = 34
    Myanmar = 35
    Georgian = 36
    Jamo = 37
    Ethiopic = 38
    Cherokee = 39
    Aboriginal = 40
    Ogham = 41
    Runic = 42
    Khmer = 43
    Mongolian = 44
    Braille = 45
    Yi = 46
    Limbu = 47
    TaiLe = 48
    NewTaiLue = 49
    SylotiNagri = 50
    Kharoshthi = 51
    Kayahli = 52
    UnicodeSymbol = 53
    Emoji = 54
    Glagolitic = 55
    Lisu = 56
    Vai = 57
    NKo = 58
    Osmanya = 59
    PhagsPa = 60
    Gothic = 61
    Deseret = 62
    Tifinagh = 63
class TextSetOptions(Enum, UInt32):
    None_ = 0
    UnicodeBidi = 1
    Unlink = 8
    Unhide = 16
    CheckTextLimit = 32
    FormatRtf = 8192
    ApplyRtfDocumentDefaults = 16384
class UnderlineType(Enum, Int32):
    Undefined = 0
    None_ = 1
    Single = 2
    Words = 3
    Double = 4
    Dotted = 5
    Dash = 6
    DashDot = 7
    DashDotDot = 8
    Wave = 9
    Thick = 10
    Thin = 11
    DoubleWave = 12
    HeavyWave = 13
    LongDash = 14
    ThickDash = 15
    ThickDashDot = 16
    ThickDashDotDot = 17
    ThickDotted = 18
    ThickLongDash = 19
class VerticalCharacterAlignment(Enum, Int32):
    Top = 0
    Baseline = 1
    Bottom = 2


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Markup
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage.Streams
import win32more.Windows.UI.Xaml.Interop
class IComponentConnector(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IComponentConnector'
    _iid_ = Guid('{ad401812-b091-51d0-b915-2d682cd2af10}')
    @winrt_commethod(6)
    def Connect(self, connectionId: Int32, target: IInspectable) -> Void: ...
    @winrt_commethod(7)
    def GetBindingConnector(self, connectionId: Int32, target: IInspectable) -> win32more.Microsoft.UI.Xaml.Markup.IComponentConnector: ...
class IDataTemplateComponent(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IDataTemplateComponent'
    _iid_ = Guid('{1743ddf7-38ba-58c9-a2a6-b0ae28713bee}')
    @winrt_commethod(6)
    def Recycle(self) -> Void: ...
    @winrt_commethod(7)
    def ProcessBindings(self, item: IInspectable, itemIndex: Int32, phase: Int32, nextPhase: POINTER(Int32)) -> Void: ...
class IMarkupExtension(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IMarkupExtension'
    _iid_ = Guid('{c355371e-091d-5136-af4a-baf5e00616bd}')
class IMarkupExtensionFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IMarkupExtensionFactory'
    _iid_ = Guid('{20651afa-5f3a-5f0c-adb1-b6551f53a6a0}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Markup.MarkupExtension: ...
class IMarkupExtensionOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IMarkupExtensionOverrides'
    _iid_ = Guid('{a12aa575-5d31-5b68-a30f-8495412a351d}')
    @winrt_commethod(6)
    def ProvideValue(self) -> IInspectable: ...
    @winrt_commethod(7)
    def ProvideValueWithIXamlServiceProvider(self, serviceProvider: win32more.Microsoft.UI.Xaml.IXamlServiceProvider) -> IInspectable: ...
class IProvideValueTarget(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IProvideValueTarget'
    _iid_ = Guid('{3f01ff68-3efd-591d-a506-de13fcaabd83}')
    @winrt_commethod(6)
    def get_TargetObject(self) -> IInspectable: ...
    @winrt_commethod(7)
    def get_TargetProperty(self) -> IInspectable: ...
    TargetObject = property(get_TargetObject, None)
    TargetProperty = property(get_TargetProperty, None)
class IProvideValueTargetProperty(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IProvideValueTargetProperty'
    _iid_ = Guid('{ce777b1f-b42e-59d1-870d-12fdf0629133}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Type(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(8)
    def get_DeclaringType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    DeclaringType = property(get_DeclaringType, None)
    Name = property(get_Name, None)
    Type = property(get_Type, None)
class IRootObjectProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IRootObjectProvider'
    _iid_ = Guid('{13d63599-352f-5eb8-81c1-bc62fb12d6da}')
    @winrt_commethod(6)
    def get_RootObject(self) -> IInspectable: ...
    RootObject = property(get_RootObject, None)
class IUriContext(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IUriContext'
    _iid_ = Guid('{fb8605f6-8f05-52ee-a01c-3a9e118a6ea2}')
    @winrt_commethod(6)
    def get_BaseUri(self) -> win32more.Windows.Foundation.Uri: ...
    BaseUri = property(get_BaseUri, None)
class IXamlBinaryWriter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IXamlBinaryWriter'
    _iid_ = Guid('{8fb45e3b-e689-55bf-aa11-d83b1c1cdda1}')
class IXamlBinaryWriterStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IXamlBinaryWriterStatics'
    _iid_ = Guid('{774907fc-c846-517f-abcc-c3f7e8c3ffc9}')
    @winrt_commethod(6)
    def Write(self, inputStreams: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Storage.Streams.IRandomAccessStream], outputStreams: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Storage.Streams.IRandomAccessStream], xamlMetadataProvider: win32more.Microsoft.UI.Xaml.Markup.IXamlMetadataProvider) -> win32more.Microsoft.UI.Xaml.Markup.XamlBinaryWriterErrorInformation: ...
class IXamlBindScopeDiagnostics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IXamlBindScopeDiagnostics'
    _iid_ = Guid('{3ea84e4e-fdfe-55a8-a561-edf5697846d7}')
    @winrt_commethod(6)
    def Disable(self, lineNumber: Int32, columnNumber: Int32) -> Void: ...
class IXamlBindingHelper(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IXamlBindingHelper'
    _iid_ = Guid('{607a9bf2-5a6d-5c89-a756-bb44f24f28f8}')
class IXamlBindingHelperStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics'
    _iid_ = Guid('{93c7dad3-f9c2-5372-84dc-9e9c4661d083}')
    @winrt_commethod(6)
    def get_DataTemplateComponentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def GetDataTemplateComponent(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Markup.IDataTemplateComponent: ...
    @winrt_commethod(8)
    def SetDataTemplateComponent(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.Markup.IDataTemplateComponent) -> Void: ...
    @winrt_commethod(9)
    def SuspendRendering(self, target: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(10)
    def ResumeRendering(self, target: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(11)
    def ConvertValue(self, type: win32more.Windows.UI.Xaml.Interop.TypeName, value: IInspectable) -> IInspectable: ...
    @winrt_commethod(12)
    def SetPropertyFromString(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: WinRT_String) -> Void: ...
    @winrt_commethod(13)
    def SetPropertyFromBoolean(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def SetPropertyFromChar16(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Char) -> Void: ...
    @winrt_commethod(15)
    def SetPropertyFromDateTime(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(16)
    def SetPropertyFromDouble(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Double) -> Void: ...
    @winrt_commethod(17)
    def SetPropertyFromInt32(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Int32) -> Void: ...
    @winrt_commethod(18)
    def SetPropertyFromUInt32(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: UInt32) -> Void: ...
    @winrt_commethod(19)
    def SetPropertyFromInt64(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Int64) -> Void: ...
    @winrt_commethod(20)
    def SetPropertyFromUInt64(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: UInt64) -> Void: ...
    @winrt_commethod(21)
    def SetPropertyFromSingle(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Single) -> Void: ...
    @winrt_commethod(22)
    def SetPropertyFromPoint(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: win32more.Windows.Foundation.Point) -> Void: ...
    @winrt_commethod(23)
    def SetPropertyFromRect(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: win32more.Windows.Foundation.Rect) -> Void: ...
    @winrt_commethod(24)
    def SetPropertyFromSize(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: win32more.Windows.Foundation.Size) -> Void: ...
    @winrt_commethod(25)
    def SetPropertyFromTimeSpan(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(26)
    def SetPropertyFromByte(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Byte) -> Void: ...
    @winrt_commethod(27)
    def SetPropertyFromUri(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(28)
    def SetPropertyFromObject(self, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: IInspectable) -> Void: ...
    DataTemplateComponentProperty = property(get_DataTemplateComponentProperty, None)
class IXamlMarkupHelper(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IXamlMarkupHelper'
    _iid_ = Guid('{cd677310-3b06-5a13-b31a-401849570858}')
class IXamlMarkupHelperStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IXamlMarkupHelperStatics'
    _iid_ = Guid('{d9a0f6e3-c6cc-5cb6-8999-85788701f339}')
    @winrt_commethod(6)
    def UnloadObject(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
class IXamlMember(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IXamlMember'
    _iid_ = Guid('{bf3a2913-5c63-50ec-8660-61809be7b9b9}')
    @winrt_commethod(6)
    def get_IsAttachable(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_IsDependencyProperty(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_IsReadOnly(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_TargetType(self) -> win32more.Microsoft.UI.Xaml.Markup.IXamlType: ...
    @winrt_commethod(11)
    def get_Type(self) -> win32more.Microsoft.UI.Xaml.Markup.IXamlType: ...
    @winrt_commethod(12)
    def GetValue(self, instance: IInspectable) -> IInspectable: ...
    @winrt_commethod(13)
    def SetValue(self, instance: IInspectable, value: IInspectable) -> Void: ...
    IsAttachable = property(get_IsAttachable, None)
    IsDependencyProperty = property(get_IsDependencyProperty, None)
    IsReadOnly = property(get_IsReadOnly, None)
    Name = property(get_Name, None)
    TargetType = property(get_TargetType, None)
    Type = property(get_Type, None)
class IXamlMetadataProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IXamlMetadataProvider'
    _iid_ = Guid('{a96251f0-2214-5d53-8746-ce99a2593cd7}')
    @winrt_commethod(6)
    def GetXamlType(self, type: win32more.Windows.UI.Xaml.Interop.TypeName) -> win32more.Microsoft.UI.Xaml.Markup.IXamlType: ...
    @winrt_commethod(7)
    def GetXamlTypeByFullName(self, fullName: WinRT_String) -> win32more.Microsoft.UI.Xaml.Markup.IXamlType: ...
    @winrt_commethod(8)
    def GetXmlnsDefinitions(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Markup.XmlnsDefinition]: ...
class IXamlReader(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IXamlReader'
    _iid_ = Guid('{54ce54c8-38c6-50d9-ac98-4b03eddbde9f}')
class IXamlReaderStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IXamlReaderStatics'
    _iid_ = Guid('{82a4cd9e-435e-5aeb-8c4f-300cece45cae}')
    @winrt_commethod(6)
    def Load(self, xaml: WinRT_String) -> IInspectable: ...
    @winrt_commethod(7)
    def LoadWithInitialTemplateValidation(self, xaml: WinRT_String) -> IInspectable: ...
class IXamlType(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IXamlType'
    _iid_ = Guid('{d24219df-7ec9-57f1-a27b-6af251d9c5bc}')
    @winrt_commethod(6)
    def get_BaseType(self) -> win32more.Microsoft.UI.Xaml.Markup.IXamlType: ...
    @winrt_commethod(7)
    def get_ContentProperty(self) -> win32more.Microsoft.UI.Xaml.Markup.IXamlMember: ...
    @winrt_commethod(8)
    def get_FullName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_IsArray(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_IsCollection(self) -> Boolean: ...
    @winrt_commethod(11)
    def get_IsConstructible(self) -> Boolean: ...
    @winrt_commethod(12)
    def get_IsDictionary(self) -> Boolean: ...
    @winrt_commethod(13)
    def get_IsMarkupExtension(self) -> Boolean: ...
    @winrt_commethod(14)
    def get_IsBindable(self) -> Boolean: ...
    @winrt_commethod(15)
    def get_ItemType(self) -> win32more.Microsoft.UI.Xaml.Markup.IXamlType: ...
    @winrt_commethod(16)
    def get_KeyType(self) -> win32more.Microsoft.UI.Xaml.Markup.IXamlType: ...
    @winrt_commethod(17)
    def get_BoxedType(self) -> win32more.Microsoft.UI.Xaml.Markup.IXamlType: ...
    @winrt_commethod(18)
    def get_UnderlyingType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(19)
    def ActivateInstance(self) -> IInspectable: ...
    @winrt_commethod(20)
    def CreateFromString(self, value: WinRT_String) -> IInspectable: ...
    @winrt_commethod(21)
    def GetMember(self, name: WinRT_String) -> win32more.Microsoft.UI.Xaml.Markup.IXamlMember: ...
    @winrt_commethod(22)
    def AddToVector(self, instance: IInspectable, value: IInspectable) -> Void: ...
    @winrt_commethod(23)
    def AddToMap(self, instance: IInspectable, key: IInspectable, value: IInspectable) -> Void: ...
    @winrt_commethod(24)
    def RunInitializer(self) -> Void: ...
    BaseType = property(get_BaseType, None)
    BoxedType = property(get_BoxedType, None)
    ContentProperty = property(get_ContentProperty, None)
    FullName = property(get_FullName, None)
    IsArray = property(get_IsArray, None)
    IsBindable = property(get_IsBindable, None)
    IsCollection = property(get_IsCollection, None)
    IsConstructible = property(get_IsConstructible, None)
    IsDictionary = property(get_IsDictionary, None)
    IsMarkupExtension = property(get_IsMarkupExtension, None)
    ItemType = property(get_ItemType, None)
    KeyType = property(get_KeyType, None)
    UnderlyingType = property(get_UnderlyingType, None)
class IXamlTypeResolver(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Markup.IXamlTypeResolver'
    _iid_ = Guid('{3fa15615-cacf-547f-b1ed-89dae8c67452}')
    @winrt_commethod(6)
    def Resolve(self, qualifiedTypeName: WinRT_String) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
class MarkupExtension(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Markup.IMarkupExtension
    _classid_ = 'Microsoft.UI.Xaml.Markup.MarkupExtension'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Markup.MarkupExtension.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Markup.IMarkupExtensionFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Markup.MarkupExtension: ...
    @winrt_mixinmethod
    def ProvideValue(self: win32more.Microsoft.UI.Xaml.Markup.IMarkupExtensionOverrides) -> IInspectable: ...
    @winrt_mixinmethod
    def ProvideValueWithIXamlServiceProvider(self: win32more.Microsoft.UI.Xaml.Markup.IMarkupExtensionOverrides, serviceProvider: win32more.Microsoft.UI.Xaml.IXamlServiceProvider) -> IInspectable: ...
class ProvideValueTargetProperty(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Markup.IProvideValueTargetProperty
    _classid_ = 'Microsoft.UI.Xaml.Markup.ProvideValueTargetProperty'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Markup.ProvideValueTargetProperty.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Markup.ProvideValueTargetProperty: ...
    @winrt_mixinmethod
    def get_Name(self: win32more.Microsoft.UI.Xaml.Markup.IProvideValueTargetProperty) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Type(self: win32more.Microsoft.UI.Xaml.Markup.IProvideValueTargetProperty) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_mixinmethod
    def get_DeclaringType(self: win32more.Microsoft.UI.Xaml.Markup.IProvideValueTargetProperty) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    DeclaringType = property(get_DeclaringType, None)
    Name = property(get_Name, None)
    Type = property(get_Type, None)
class XamlBinaryWriter(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Markup.IXamlBinaryWriter
    _classid_ = 'Microsoft.UI.Xaml.Markup.XamlBinaryWriter'
    @winrt_classmethod
    def Write(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBinaryWriterStatics, inputStreams: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Storage.Streams.IRandomAccessStream], outputStreams: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Storage.Streams.IRandomAccessStream], xamlMetadataProvider: win32more.Microsoft.UI.Xaml.Markup.IXamlMetadataProvider) -> win32more.Microsoft.UI.Xaml.Markup.XamlBinaryWriterErrorInformation: ...
class XamlBinaryWriterErrorInformation(Structure):
    InputStreamIndex: UInt32
    LineNumber: UInt32
    LinePosition: UInt32
class _XamlBindingHelper_Meta_(ComPtr.__class__):
    pass
class XamlBindingHelper(ComPtr, metaclass=_XamlBindingHelper_Meta_):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelper
    _classid_ = 'Microsoft.UI.Xaml.Markup.XamlBindingHelper'
    @winrt_classmethod
    def get_DataTemplateComponentProperty(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetDataTemplateComponent(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Markup.IDataTemplateComponent: ...
    @winrt_classmethod
    def SetDataTemplateComponent(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.Markup.IDataTemplateComponent) -> Void: ...
    @winrt_classmethod
    def SuspendRendering(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, target: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_classmethod
    def ResumeRendering(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, target: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_classmethod
    def ConvertValue(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, type: win32more.Windows.UI.Xaml.Interop.TypeName, value: IInspectable) -> IInspectable: ...
    @winrt_classmethod
    def SetPropertyFromString(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: WinRT_String) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromBoolean(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Boolean) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromChar16(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Char) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromDateTime(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromDouble(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Double) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromInt32(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Int32) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromUInt32(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: UInt32) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromInt64(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Int64) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromUInt64(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: UInt64) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromSingle(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Single) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromPoint(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: win32more.Windows.Foundation.Point) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromRect(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: win32more.Windows.Foundation.Rect) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromSize(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: win32more.Windows.Foundation.Size) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromTimeSpan(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromByte(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: Byte) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromUri(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_classmethod
    def SetPropertyFromObject(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlBindingHelperStatics, dependencyObject: IInspectable, propertyToSet: win32more.Microsoft.UI.Xaml.DependencyProperty, value: IInspectable) -> Void: ...
    _XamlBindingHelper_Meta_.DataTemplateComponentProperty = property(get_DataTemplateComponentProperty, None)
class XamlMarkupHelper(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Markup.IXamlMarkupHelper
    _classid_ = 'Microsoft.UI.Xaml.Markup.XamlMarkupHelper'
    @winrt_classmethod
    def UnloadObject(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlMarkupHelperStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
class XamlReader(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Markup.IXamlReader
    _classid_ = 'Microsoft.UI.Xaml.Markup.XamlReader'
    @winrt_classmethod
    def Load(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlReaderStatics, xaml: WinRT_String) -> IInspectable: ...
    @winrt_classmethod
    def LoadWithInitialTemplateValidation(cls: win32more.Microsoft.UI.Xaml.Markup.IXamlReaderStatics, xaml: WinRT_String) -> IInspectable: ...
class XmlnsDefinition(Structure):
    XmlNamespace: WinRT_String
    Namespace: WinRT_String


make_ready(__name__)
